@@ -76,6 +76,22 @@ pub(crate) const ZERO_TRESHOLD: Scalar = 1e-6;
 mod tests {
     use super::*;
 
+    #[test]
+    fn test_send_sync() {
+        fn foo<T>()
+        where
+            T: Send + Sync,
+        {
+            println!("{:?} is Send + Sync", std::any::type_name::<T>());
+        }
+
+        foo::<NavMesh>();
+        foo::<NavNet>();
+        foo::<NavGrid>();
+        foo::<NavFreeGrid>();
+        foo::<NavIslands<(), ()>>();
+    }
+
     #[test]
     fn test_raycast() {
         assert_eq!(
@@ -774,6 +790,21 @@ mod tests {
         let path = grid.find_path((0, 0), (0, 1)).unwrap();
         assert_eq!(path, vec![(0, 0), (1, 0), (1, 1), (0, 1)]);
 
+        let grid = NavGrid::new(
+            3,
+            3,
+            vec![true, true, true, false, false, false, true, true, true],
+        )
+        .unwrap();
+        let mut islands = grid.find_islands();
+        for island in &mut islands {
+            island.sort();
+        }
+        assert_eq!(
+            islands,
+            vec![vec![(0, 0), (1, 0), (2, 0)], vec![(0, 2), (1, 2), (2, 2)]]
+        );
+
         let grid = NavFreeGrid::new(vec![
             NavFreeGridConnection {
                 from: (0, 0),
